==> sawmill6.4b3_crypt_src.tar.gz: sawmill-6.4b3/S2eb3c727bb6ce2eb4b7860430567d0aa.cpp <==
//
// Sawmill Source Code
// 
// This source code is the intellectual property of Flowerfire,
// and is protected by federal trade secret laws.  Do not
// redistribute, modify, or use this source code, except to compile
// it, without the express written consent of Flowerfire.
//
// For more information, see http://www.sawmill.net/trade_secret.html
//
// The trial and full commercial licenses for Sawmill allow you
// to use the program, and to compile it from this source code,
// but you are not permitted to look at this source code.  Please
// do not attempt to use this source code for any purpose other 
// then compilation!



















































 const char *Se843c81f6f6ee3e2383f92c1a1c2f161[] = { "# This language module contains templates for HTML files.\n", 
"# This does not need to be translated; it contains no English.\n", "# It is useful if you want to modify the %22look and feel%22 of the \n", 
"# interface.\n", "\n", "# The style sheet\n", "STYLE_SHEET\n", "\"<style type=%22text/css%22>\n", "{QUOTE:\n", 
"body, tr, td, br, p {\n", "	font-family : arial, verdana, times;\n", "	font-size : 10pt;\n", "	color : #2F2F2F;\n", 
"}\n", "\n", "li{\n", "	list-style : disc;\n", "	color : #2F2F2F;\n", "}\n", "\n", "hr{\n", "	text-align : center;\n", 
"	width : 700px;\n", "	height : 1px;\n", "	color:#3C5677;\n", "}\n", "\n", "A:ACTIVE, A:LINK, A:VISITED {\n", 
"	color:#3C5677;\n", "	font-size : 10pt;\n", "	text-decoration: none;\n", "	font-weight:bold\n", "}\n", 
"\n", "A:HOVER {\n", "	color : #7793B1;\n", "	font-size : 10pt;\n", "	text-decoration: none;\n", "	font-weight:bold\n", 
"}\n", "\n", ".link {\n", "	color : #3C5677;\n", "	font-size : 10pt;\n", "	text-decoration: none;\n", 
"	font-weight:normal;\n", "}\n", "\n", ".smallwhite{\n", "	font-size: 9pt;\n", "	color:#FFFFFF;\n", 
"	text-decoration: none;\n", "	font-weight:bolder;\n", "	text-align:center\n", "}\n", "\n", ".date{\n", 
"	font-family : arial, verdana, times;\n", "	font-size : 10pt;\n", "	color : #000000;\n", "	text-align : justify;\n", 
"	font-weight:bold;\n", "}\n", "\n", ".smheader{\n", "	font-size : 10pt;\n", "	color : #2F2F2F;\n", 
"	font-weight : bold;\n", "}\n", "\n", ".bgheader{\n", "	font-size : 10pt;\n", "	color : #2F2F2F;\n", 
"	font-weight : bold;\n", "}\n", "\n", "\n", ".bgtext{\n", "	font-family : arial, verdana, times;\n", 
"	font-size : 10pt;\n", "	font-weight:bold;\n", "	color : #2F2F2F;\n", "	text-align : right;\n", "}\n", 
"\n", "input{\n", "	border-color : Black;\n", "	border : 1px solid;\n", "}\n", "\n", ".docspagetitle {\n", 
"       font-family: arial, verdana, helvetica;\n", "	font-size : 18pt;\n", "	color : #2F2F2F;\n", "	font-weight : bold;\n", 
"	text-align : center;\n", "}\n", "\n", ".docstitle {\n", "	font-size : 28pt;\n", "	color : #6F8CAD;\n", 
"	font-weight : bold;\n", "	text-align : center;\n", "}\n", "\n", "}\n", "</style>\n", "\"\n", "\n", 
"# The header of documentation page\n", "DOCS_HEADER_TEMPLATE\n", "\"<html>\n", "\n", "<head>\n", "<meta http-equiv=%22Content-Language%22 content=%22en-us%22>\n", 
"<meta http-equiv=%22Content-Type%22 content=%22text/html; charset=windows-1252%22>\n", "<title>{PRODUCT_NAME}: {DOCS_PAGE_LABEL}</title>\n", 
"{STYLE_SHEET}\n", "</head>\n", "\n", "<body>\n", "\n", "{STARTFORM}\n", "<table border=%220%22 cellpadding=%220%22 cellspacing=%220%22 style=%22border-collapse: collapse%22 bordercolor=%22#111111%22 width=%22700%22>\n", 
"  <tr>\n", "    <td width=%22146%22 style=%22text-align: left%22 valign=%22bottom%22>\n", "    \n", 
"    {IMAGE:docslogo.gif:92:44}\n", "    <td width=%22598%22 style=%22text-align: right%22 valign=%22bottom%22>\n", 
"      <p style=%22text-align: right%22>\n", "      <input type=%22text%22 name=%22searchdocstext%22 size=%2217%22><font color=%22#4E719A%22> <input type=%22submit%22 value=%22{SEARCH_BUTTON}%22 name=%22searchdocs%22 style=%22border:1px solid #000000; color: #FFFFFF; font-family: Arial; font-size: 10pt; font-weight: bold; height: 20; background-color: #4E719A%22></font></td>\n", 
"  </tr>\n", "</table>\n", "\n", "<table border=%220%22 cellpadding=%220%22 cellspacing=%220%22 style=%22border-collapse: collapse%22 bordercolor=%22#111111%22 width=%22700%22 height=%221%22>\n", 
"  <tr>\n", "    <td width=%22100%22 bgcolor=%22#99AEC5%22 height=%221%22>\n", "    <p style=%22text-align: left%22>\n", 
"&nbsp;</td>\n", "    <td height=%223%22 width=%223%22 bgcolor=%22#ffffff%22><spacer type=%22block%22 width=%223%22 height=%223%22></td>\n", 
"    <td height=%221%22 valign=%22bottom%22 bgcolor=%22#{IFEQUAL:{DOCS_TAB}:TOC:THEN:2F2F2F:ELSE:99AEC5}%22>\n", 
"    <p align=%22center%22 style=%22text-align: center%22><span class=smallwhite>\n", "    <a href=%22{PRODUCT_EXECUTABLE}?ho+docs-toc%22>\n", 
"    <font color=%22#{IFEQUAL:{DOCS_TAB}:TOC:THEN:FFFFFF:ELSE:2F2F2F}%22><b>\n", "    {TOC_LABEL}\n", 
"    </b></font>\n", "    </a>\n", "    </td>\n", "    <td height=%223%22 width=%223%22 bgcolor=%22#ffffff%22><spacer type=%22block%22 width=%223%22 height=%223%22></td>\n", 
"    <td height=%221%22 valign=%22bottom%22 bgcolor=%22{IFEQUAL:{DOCS_TAB}:FAQ:THEN:2F2F2F:ELSE:99AEC5}%22>\n", 
"    <p align=%22center%22 style=%22text-align: center%22>\n", "    <a href=%22{PRODUCT_EXECUTABLE}?ho+docs-faq%22>\n", 
"    <font color=%22#{IFEQUAL:{DOCS_TAB}:FAQ:THEN:FFFFFF:ELSE:2F2F2F}%22><b>\n", "    {FAQ_LABEL}\n", 
"    </b></font>\n", "    </a>\n", "    </td>\n", "    <td height=%223%22 width=%223%22 bgcolor=%22#ffffff%22><spacer type=%22block%22 width=%223%22 height=%223%22></td>\n", 
"    <td height=%221%22 valign=%22bottom%22 bgcolor=%22#99AEC5%22>\n", "    <p style=%22text-align: center%22>\n", 
"    <a href=%22{PRODUCT_EXECUTABLE}?admin%22>\n", "    <font color=%22#000000%22>{ADMINISTRATIVE_MENU}</font></a></td>\n", 
"    <td height=%223%22 width=%223%22 bgcolor=%22#ffffff%22><spacer type=%22block%22 width=%223%22 height=%223%22></td>\n", 
"    <td height=%221%22 valign=%22bottom%22 bgcolor=%22#99AEC5%22>\n", "    <p style=%22text-align: center%22><a href=%22{PRODUCT_URL}%22>\n", 
"    <font color=%22#000000%22>{PRODUCT_WEB_SITE}</font></a></td>\n", "    <td height=%223%22 width=%223%22 bgcolor=%22#ffffff%22><spacer type=%22block%22 width=%223%22 height=%223%22></td>\n", 
"    <td width=%22100%22 height=%221%22 bgcolor=%22#99AEC5%22>\n", "&nbsp;</td>\n", "  </tr>\n", "  </table>\n", 
"\n", "<table border=%220%22 cellpadding=%220%22 cellspacing=%220%22 style=%22border-collapse: collapse%22 bordercolor=%22#111111%22 width=%22700%22 height=%221%22>\n", 
"  <tr>\n", "    <td height=%223%22 width=%223%22 bgcolor=%22#ffffff%22><spacer type=%22block%22 width=%223%22 height=%223%22></td>\n", 
"  </tr>\n", "  <tr>\n", "    <td align=%22center%22 height=%2242%22 bgcolor=%22#4c6898%22>\n", "    <span class=docstitle>{DOCUMENTATION_TITLE}</span>\n", 
"    <td align=right width=%221%22 height=%2242%22 valign=%22top%22 bgcolor=%22#4C6898%22>\n", "    {IMAGE:docspicture.gif:350:48}</td>\n", 
"  </tr>\n", "  <tr>\n", "    <td height=%226%22 width=%223%22 bgcolor=%22#ffffff%22><spacer type=%22block%22 width=%223%22 height=%226%22></td>\n", 
"  </tr>\n", "  <tr>\n", "    <td colspan=%222%22 align=%22center%22 bgcolor=%22#99AEC5%22 width=%22100%25%22><span class=docspagetitle>{DOCS_PAGE_LABEL}</span></td>\n", 
"  </tr>\n", "</table>\n", "\"\n", "\n", "\n", "# This is the template for the footer of documentation page\n", 
"DOCS_FOOTER_TEMPLATE\n", "\"</body>\n", "</html>\"\n", "\n", "\n", "# This is the template for a FAQ entry page contents\n", 
"FAQ_ENTRY_CONTENTS_TEMPLATE\n", "\"<table border=%220%22 cellpadding=%220%22 cellspacing=%220%22 style=%22border-collapse: collapse%22 bordercolor=%22#111111%22 width=%2276%%22 height=%2213%22>\n", 
"  <tr>\n", "<td width=%22100%%22 height=%2213%22><b>{FAQ_QUESTION_LABEL}</b>: <br>\n", "{QUESTION}\n", 
"    <hr>\n", "<p><b>{FAQ_SHORT_ANSWER_LABEL}</b>: <br>\n", "{SHORT_ANSWER_CONTENTS} </p>\n", "    <hr>\n", 
"<p><b>{FAQ_LONG_ANSWER_LABEL}:<br>\n", "    </b>{FAQ_LONG_ANSWER_CONTENTS}</p>\n", "    <p>&nbsp;</td>\n", 
"  </tr>\n", "</table>\"\n", "\n", "\n", "# This defines the layout of a single full FAQ page\n", "FAQ_PAGE \"\n", 
"<font size=+1><b>Question</b></font>: {FAQ_QUESTION_{FAQPAGENAME}}<p>\n", "<hr><p>\n", "<font size=+1><b>Short Answer</b></font>: {FAQ_SHORT_ANSWER_{FAQPAGENAME}}<p>\n", 
"<hr><p>\n", "<font size=+1><b>Long Answer:</b></font><p>\n", "{QUOTE:{FAQ_LONG_ANSWER_{FAQPAGENAME}}}\n", 
"\"\n", "\n", "# This defines the layout of a single short FAQ entry\n", "FAQ_ENTRY \"\n", "<b>Q</b>: {FAQ_QUESTION_{FAQPAGENAME}}<br>\n", 
"<b>A</b>: {FAQ_SHORT_ANSWER_{FAQPAGENAME}} For full details, see [faq-{FAQPAGENAME}].<br>\n", "<br>\"\n", 
"\n", "\n", "\n", "# This is the template for an administrative title bar\n", "ADMIN_TITLE_BAR_TEMPLATE\n", 
"\"<table border=%220%22 cellspacing=%220%22 cellpadding=%220%22 width=%22100%%22>\n", "  <tr>\n", "    <td colspan=%224%22 height=%221%22 width=%22100%%22 bgcolor=%22{ADMIN_TITLE_BAR_COLOR_LIGHTENED}%22><spacer type=%22block%22 width=%22100%%22 height=%221%22></td>\n", 
"  </tr>\n", "  <tr>\n", "    <td colspan=%224%22 height=%221%22 width=%22100%%22 bgcolor=%22{ADMIN_TITLE_BAR_COLOR_DARKENED}%22><spacer type=%22block%22 width=%22100%%22 height=%221%22></td>\n", 
"  </tr>\n", "  <tr>\n", "    <td width=%2290%22 height=%2230%22 bgcolor=%22{ADMIN_TITLE_BAR_COLOR}%22><spacer type=%22block%22 width=%2290%22 height=%2230%22></td>\n", 
"    <td align=%22center%22 width=%22100%%22 bgcolor=%22{ADMIN_TITLE_BAR_COLOR}%22>\n" "      <font color=%22#000000%22 size=%22+2%22 face=%22Verdana,Arial,Helvetica,Geneva,SunSans-Regular,Swiss%22><b>{ADMIN_TITLE_BAR_TITLE}</b></font>\n", 
"    </td>\n", "    <td width=%2290%22 bgcolor=%22{ADMIN_TITLE_BAR_COLOR}%22>{IMAGE:title.gif}</td><td bgcolor=%22{ADMIN_TITLE_BAR_COLOR}%22>&nbsp;&nbsp;</td>\n", 
"  </tr>\n", "  <tr>\n", "    <td colspan=%224%22 height=%221%22 width=%22100%%22 bgcolor=%22{ADMIN_TITLE_BAR_COLOR_LIGHTENED}%22><spacer type=%22block%22 width=%22100%%22 height=%221%22></td>\n", 
"  </tr>\n", "  <tr>\n", "    <td colspan=%224%22 height=%221%22 width=%22100%%22 bgcolor=%22{ADMIN_TITLE_BAR_COLOR_DARKENED}%22><spacer type=%22block%22 width=%22100%%22 height=%221%22></td>\n", 
"  </tr>\n", "</table>\n", "\"\n", "\n", 0 };

==> sawmill6.4.5_crypt_src.tar.gz: sawmill-6.4.5/S2eb3c727bb6ce2eb4b7860430567d0aa.cpp <==
//
// Sawmill Source Code
// 
// This source code is the intellectual property of Flowerfire,
// and is protected by federal trade secret laws.  Do not
// redistribute, modify, or use this source code, except to compile
// it, without the express written consent of Flowerfire.
//
// For more information, see http://www.sawmill.net/trade_secret.html
//
// The trial and full commercial licenses for Sawmill allow you
// to use the program, and to compile it from this source code,
// but you are not permitted to look at this source code.  Please
// do not attempt to use this source code for any purpose other 
// than compilation!



















































 const char *Se843c81f6f6ee3e2383f92c1a1c2f161[] = { "# This language module contains templates for HTML files.\n", 
"# This does not need to be translated; it contains no English.\n", "# It is useful if you want to modify the %22look and feel%22 of the \n", 
"# interface.\n", "\n", "# The style sheet\n", "STYLE_SHEET\n", "\"<style type=%22text/css%22>\n", "{QUOTE:\n", 
"body, tr, td, br, p {\n", "	font-family : arial, verdana, times;\n", "	font-size : 10pt;\n", "	color : #2F2F2F;\n", 
"}\n", "\n", "li{\n", "	list-style : disc;\n", "	color : #2F2F2F;\n", "}\n", "\n", "hr{\n", "	text-align : center;\n", 
"	width : 700px;\n", "	height : 1px;\n", "	color:#3C5677;\n", "}\n", "\n", "A:ACTIVE, A:LINK, A:VISITED {\n", 
"	color:#3C5677;\n", "	font-size : 10pt;\n", "	text-decoration: none;\n", "	font-weight:bold\n", "}\n", 
"\n", "A:HOVER {\n", "	color : #7793B1;\n", "	font-size : 10pt;\n", "	text-decoration: none;\n", "	font-weight:bold\n", 
"}\n", "\n", ".link {\n", "	color : #3C5677;\n", "	font-size : 10pt;\n", "	text-decoration: none;\n", 
"	font-weight:normal;\n", "}\n", "\n", ".smallwhite{\n", "	font-size: 9pt;\n", "	color:#FFFFFF;\n", 
"	text-decoration: none;\n", "	font-weight:bolder;\n", "	text-align:center\n", "}\n", "\n", ".date{\n", 
"	font-family : arial, verdana, times;\n", "	font-size : 10pt;\n", "	color : #000000;\n", "	text-align : justify;\n", 
"	font-weight:bold;\n", "}\n", "\n", ".smheader{\n", "	font-size : 10pt;\n", "	color : #2F2F2F;\n", 
"	font-weight : bold;\n", "}\n", "\n", ".bgheader{\n", "	font-size : 10pt;\n", "	color : #2F2F2F;\n", 
"	font-weight : bold;\n", "}\n", "\n", "\n", ".bgtext{\n", "	font-family : arial, verdana, times;\n", 
"	font-size : 10pt;\n", "	font-weight:bold;\n", "	color : #2F2F2F;\n", "	text-align : right;\n", "}\n", 
"\n", "input{\n", "	border-color : Black;\n", "	border : 1px solid;\n", "}\n", "\n", ".docspagetitle {\n", 
"       font-family: arial, verdana, helvetica;\n", "	font-size : 18pt;\n", "	color : #2F2F2F;\n", "	font-weight : bold;\n", 
"	text-align : center;\n", "}\n", "\n", ".docstitle {\n", "	font-size : 28pt;\n", "	color : #6F8CAD;\n", 
"	font-weight : bold;\n", "	text-align : center;\n", "}\n", "\n", "}\n", "</style>\n", "\"\n", "\n", 
"# The header of documentation page\n", "DOCS_HEADER_TEMPLATE\n", "\"<html>\n", "\n", "<head>\n", "<meta http-equiv=%22Content-Language%22 content=%22en-us%22>\n", 
"<meta http-equiv=%22Content-Type%22 content=%22text/html; charset=windows-1252%22>\n", "<title>{PRODUCT_NAME}: {DOCS_PAGE_LABEL}</title>\n", 
"{STYLE_SHEET}\n", "</head>\n", "\n", "<body>\n", "\n", "{STARTFORM}\n", "<table border=%220%22 cellpadding=%220%22 cellspacing=%220%22 style=%22border-collapse: collapse%22 bordercolor=%22#111111%22 width=%22700%22>\n", 
"  <tr>\n", "    <td width=%22146%22 style=%22text-align: left%22 valign=%22bottom%22>\n", "    \n", 
"    {IMAGE:docslogo.gif:92:44}\n", "    <td width=%22598%22 style=%22text-align: right%22 valign=%22bottom%22>\n", 
"      <p style=%22text-align: right%22>\n", "      <input type=%22text%22 name=%22searchdocstext%22 size=%2217%22><font color=%22#4E719A%22> <input type=%22submit%22 value=%22{SEARCH_BUTTON}%22 name=%22searchdocs%22 style=%22border:1px solid #000000; color: #FFFFFF; font-family: Arial; font-size: 10pt; font-weight: bold; height: 20; background-color: #4E719A%22></font></td>\n", 
"  </tr>\n", "</table>\n", "\n", "<table border=%220%22 cellpadding=%220%22 cellspacing=%220%22 style=%22border-collapse: collapse%22 bordercolor=%22#111111%22 width=%22700%22 height=%221%22>\n", 
"  <tr>\n", "    <td width=%22100%22 bgcolor=%22#99AEC5%22 height=%221%22>\n", "    <p style=%22text-align: left%22>\n", 
"&nbsp;</td>\n", "    <td height=%223%22 width=%223%22 bgcolor=%22#ffffff%22><spacer type=%22block%22 width=%223%22 height=%223%22></td>\n", 
"    <td height=%221%22 valign=%22bottom%22 bgcolor=%22#{IFEQUAL:{DOCS_TAB}:TOC:THEN:2F2F2F:ELSE:99AEC5}%22>\n", 
"    <p align=%22center%22 style=%22text-align: center%22><span class=smallwhite>\n", "    <a href=%22{PRODUCT_EXECUTABLE}?ho+docs-toc%22>\n", 
"    <font color=%22#{IFEQUAL:{DOCS_TAB}:TOC:THEN:FFFFFF:ELSE:2F2F2F}%22><b>\n", "    {TOC_LABEL}\n", 
"    </b></font>\n", "    </a>\n", "    </td>\n", "    <td height=%223%22 width=%223%22 bgcolor=%22#ffffff%22><spacer type=%22block%22 width=%223%22 height=%223%22></td>\n", 
"    <td height=%221%22 valign=%22bottom%22 bgcolor=%22{IFEQUAL:{DOCS_TAB}:FAQ:THEN:2F2F2F:ELSE:99AEC5}%22>\n", 
"    <p align=%22center%22 style=%22text-align: center%22>\n", "    <a href=%22{PRODUCT_EXECUTABLE}?ho+docs-faq%22>\n", 
"    <font color=%22#{IFEQUAL:{DOCS_TAB}:FAQ:THEN:FFFFFF:ELSE:2F2F2F}%22><b>\n", "    {FAQ_LABEL}\n", 
"    </b></font>\n", "    </a>\n", "    </td>\n", "    <td height=%223%22 width=%223%22 bgcolor=%22#ffffff%22><spacer type=%22block%22 width=%223%22 height=%223%22></td>\n", 
"    <td height=%221%22 valign=%22bottom%22 bgcolor=%22#99AEC5%22>\n", "    <p style=%22text-align: center%22>\n", 
"    <a href=%22{PRODUCT_EXECUTABLE}?admin%22>\n", "    <font color=%22#000000%22>{ADMINISTRATIVE_MENU}</font></a></td>\n", 
"    <td height=%223%22 width=%223%22 bgcolor=%22#ffffff%22><spacer type=%22block%22 width=%223%22 height=%223%22></td>\n", 
"    <td height=%221%22 valign=%22bottom%22 bgcolor=%22#99AEC5%22>\n", "    <p style=%22text-align: center%22><a href=%22{PRODUCT_URL}%22>\n", 
"    <font color=%22#000000%22>{PRODUCT_WEB_SITE}</font></a></td>\n", "    <td height=%223%22 width=%223%22 bgcolor=%22#ffffff%22><spacer type=%22block%22 width=%223%22 height=%223%22></td>\n", 
"    <td width=%22100%22 height=%221%22 bgcolor=%22#99AEC5%22>\n", "&nbsp;</td>\n", "  </tr>\n", "  </table>\n", 
"\n", "<table border=%220%22 cellpadding=%220%22 cellspacing=%220%22 style=%22border-collapse: collapse%22 bordercolor=%22#111111%22 width=%22700%22 height=%221%22>\n", 
"  <tr>\n", "    <td height=%223%22 width=%223%22 bgcolor=%22#ffffff%22><spacer type=%22block%22 width=%223%22 height=%223%22></td>\n", 
"  </tr>\n", "  <tr>\n", "    <td align=%22center%22 height=%2242%22 bgcolor=%22#4c6898%22>\n", "    <span class=docstitle>{DOCUMENTATION_TITLE}</span>\n", 
"    <td align=right width=%221%22 height=%2242%22 valign=%22top%22 bgcolor=%22#4C6898%22>\n", "    {IMAGE:docspicture.gif:350:48}</td>\n", 
"  </tr>\n", "  <tr>\n", "    <td height=%226%22 width=%223%22 bgcolor=%22#ffffff%22><spacer type=%22block%22 width=%223%22 height=%226%22></td>\n", 
"  </tr>\n", "  <tr>\n", "    <td colspan=%222%22 align=%22center%22 bgcolor=%22#99AEC5%22 width=%22100%25%22><span class=docspagetitle>{DOCS_PAGE_LABEL}</span></td>\n", 
"  </tr>\n", "</table>\n", "\"\n", "\n", "\n", "# This is the template for the footer of documentation page\n", 
"DOCS_FOOTER_TEMPLATE\n", "\"</body>\n", "</html>\"\n", "\n", "\n", "# This is the template for a FAQ entry page contents\n", 
"FAQ_ENTRY_CONTENTS_TEMPLATE\n", "\"<table border=%220%22 cellpadding=%220%22 cellspacing=%220%22 style=%22border-collapse: collapse%22 bordercolor=%22#111111%22 width=%2276%%22 height=%2213%22>\n", 
"  <tr>\n", "<td width=%22100%%22 height=%2213%22><b>{FAQ_QUESTION_LABEL}</b>: <br>\n", "{QUESTION}\n", 
"    <hr>\n", "<p><b>{FAQ_SHORT_ANSWER_LABEL}</b>: <br>\n", "{SHORT_ANSWER_CONTENTS} </p>\n", "    <hr>\n", 
"<p><b>{FAQ_LONG_ANSWER_LABEL}:<br>\n", "    </b>{FAQ_LONG_ANSWER_CONTENTS}</p>\n", "    <p>&nbsp;</td>\n", 
"  </tr>\n", "</table>\"\n", "\n", "\n", "# This defines the layout of a single full FAQ page\n", "FAQ_PAGE \"\n", 
"<font size=+1><b>Question</b></font>: {FAQ_QUESTION_{FAQPAGENAME}}<p>\n", "<hr><p>\n", "<font size=+1><b>Short Answer</b></font>: {FAQ_SHORT_ANSWER_{FAQPAGENAME}}<p>\n", 
"<hr><p>\n", "<font size=+1><b>Long Answer:</b></font><p>\n", "{QUOTE:{FAQ_LONG_ANSWER_{FAQPAGENAME}}}\n", 
"\"\n", "\n", "# This defines the layout of a single short FAQ entry\n", "FAQ_ENTRY \"\n", "<b>Q</b>: {FAQ_QUESTION_{FAQPAGENAME}}<br>\n", 
"<b>A</b>: {FAQ_SHORT_ANSWER_{FAQPAGENAME}} For full details, see [faq-{FAQPAGENAME}].<br>\n", "<br>\"\n", 
"\n", "\n", "\n", "# This is the template for an administrative title bar\n", "ADMIN_TITLE_BAR_TEMPLATE\n", 
"\"<table border=%220%22 cellspacing=%220%22 cellpadding=%220%22 width=%22100%%22>\n", "  <tr>\n", "    <td colspan=%224%22 height=%221%22 width=%22100%%22 bgcolor=%22{ADMIN_TITLE_BAR_COLOR_LIGHTENED}%22><spacer type=%22block%22 width=%22100%%22 height=%221%22></td>\n", 
"  </tr>\n", "  <tr>\n", "    <td colspan=%224%22 height=%221%22 width=%22100%%22 bgcolor=%22{ADMIN_TITLE_BAR_COLOR_DARKENED}%22><spacer type=%22block%22 width=%22100%%22 height=%221%22></td>\n", 
"  </tr>\n", "  <tr>\n", "    <td width=%2290%22 height=%2230%22 bgcolor=%22{ADMIN_TITLE_BAR_COLOR}%22><spacer type=%22block%22 width=%2290%22 height=%2230%22></td>\n", 
"    <td align=%22center%22 width=%22100%%22 bgcolor=%22{ADMIN_TITLE_BAR_COLOR}%22>\n" "      <font color=%22#000000%22 size=%22+2%22 face=%22Verdana,Arial,Helvetica,Geneva,SunSans-Regular,Swiss%22><b>{ADMIN_TITLE_BAR_TITLE}</b></font>\n", 
"    </td>\n", "    <td width=%2290%22 bgcolor=%22{ADMIN_TITLE_BAR_COLOR}%22>\n", "    {IFEQUAL:{show_logo_in_administrative_header}:true:THEN:{IMAGE:logo.gif}:ELSE:}\n", 
"    </td><td bgcolor=%22{ADMIN_TITLE_BAR_COLOR}%22>&nbsp;&nbsp;</td>\n", "  </tr>\n", "  <tr>\n", "    <td colspan=%224%22 height=%221%22 width=%22100%%22 bgcolor=%22{ADMIN_TITLE_BAR_COLOR_LIGHTENED}%22><spacer type=%22block%22 width=%22100%%22 height=%221%22></td>\n", 
"  </tr>\n", "  <tr>\n", "    <td colspan=%224%22 height=%221%22 width=%22100%%22 bgcolor=%22{ADMIN_TITLE_BAR_COLOR_DARKENED}%22><spacer type=%22block%22 width=%22100%%22 height=%221%22></td>\n", 
"  </tr>\n", "</table>\n", "\"\n", "\n", 0 };
